package com.sf.mapper;


import com.sf.entity.SysUserInfo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @author WanJl
 * @version 1.0
 * @title SysUserInfoMapper
 * @description
 * @create 2025/11/16
 */
public interface SysUserInfoMapper {
    /**
     * 根据用户的真实姓名进行模糊查询
     * @param realName
     * @return
     */
    List<SysUserInfo> findByName1(String realName);

    List<SysUserInfo> findByName2(String realName);

    List<SysUserInfo> findByName3(String realName);

    List<SysUserInfo> findByName4(String realName);

    List<SysUserInfo> findByName5(String realName);

    /**
     * 根据集合中的id，查询多条数据
     * @param ids
     * @return
     */
    List<SysUserInfo> findByIds(@Param("ids")List<Integer> ids);

    /**
     *
     * @param start
     * @param end
     * @return
     */
    List<SysUserInfo> findByIds2(@Param("start") Integer start, @Param("end") Integer end);
    /*
        @Param() 注解的作用是给参数命名，这个命名是让mybatis的映射文件能够根据名称找到正确的参数值，
        然后正确的把参数传入到SQL语句中
            |-如果Mapper接口的某个方法中有多个参数，就需要使用@Param进行命名
            |-方法的参数需要取别名
            |-配置文件xml中如果使用${}进行参数传递的时候
            |-动态SQL中使用了参数作为变量
     */
}
